The initial steps to remedy this should be determined on whether the
cookie is sensitive in nature. If the cookie does not contain any
sensitive information then the risk of this vulnerability is reduced;
however, if the cookie does contain sensitive information, then the
server should ensure that the cookie has its `secure` flag set.